#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ELSE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IF_ELSE_HPP_INCLUDED

#include <boost/simd/operator/include/functions/scalar/if_else.hpp>

#endif
